@@ -272,11 +272,27 @@
       cut <- rep(cut,length=4)
       bbox <- with(g,c(minx,miny,maxx,maxy))+cut
    }
-   if (!is.na(expand)) {
+   if (!anyNA(expand)) {
       x0 <- (g$minx+g$maxx)/2
       y0 <- (g$miny+g$maxy)/2
-      dx <- (expand[1])*(g$maxx-g$minx)/2
-      dy <- (expand[1])*(g$maxy-g$miny)/2
+      sx <- (g$maxx-g$minx)/2
+      sy <- (g$maxy-g$miny)/2
+      if (length(expand)==1) {
+         expand <- rep(expand,length.out=2)
+         s <- sqrt(sx*sy)
+         if (T) {
+            dx <- sx+round(s*(expand[1]-1)/g$resx*2)*g$resx/2
+            dy <- sy+round(s*(expand[2]-1)/g$resy*2)*g$resy/2
+         }
+         else { ## deprecated
+            dx <- sx+s*(expand[1]-1)
+            dy <- sy+s*(expand[2]-1)
+         }
+      }
+      else {
+         dx <- (expand[1])*sx
+         dy <- (expand[2])*sy
+      }
      # print(with(g,c(minx,miny,maxx,maxy)))
       bbox <- c(x0-dx,y0-dy,x0+dx,y0+dy)
      # print(bbox)
