@@ -1,18 +1,20 @@
-'ursa_proj4'   <- function(obj) .syn('ursa_proj',0,obj)
-'ursa_proj4<-' <- function(obj,keepGrid=FALSE,value) .syn('ursa_proj<-',0,obj,keepGrid,value)
-'ursa_proj' <- function(obj)
+'ursa_proj4'   <- function(obj) .syn('ursa_crs',0,obj)
+'ursa_proj4<-' <- function(obj,keepGrid=FALSE,value) .syn('ursa_crs<-',0,obj,keepGrid,value)
+'ursa_proj'   <- function(obj) .syn('ursa_crs',0,obj)
+'ursa_proj<-' <- function(obj,keepGrid=FALSE,value) .syn('ursa_crs<-',0,obj,keepGrid,value)
+'ursa_crs' <- function(obj)
 {
    if (is.ursa(obj,"stack"))
-      return(obj[[1]]$grid$proj4)
+      return(obj[[1]]$grid$crs)
    if (is.ursa(obj)) {
-      return(obj$grid$proj4)
+      return(obj$grid$crs)
    }
    if (.is.grid(obj))
-      return(obj$proj4)
+      return(obj$crs)
    if ((is.character(obj))&&(nchar(obj))&&(envi_exists(obj,exact=TRUE))) {
       g1 <- session_grid()
       a <- open_envi(obj,resetGrid=TRUE)
-      res <- a$grid$proj4
+      res <- a$grid$crs
       close(a)
       session_grid(g1)
       return(res)
@@ -23,7 +25,7 @@
    }
    NULL
 }
-'ursa_proj<-' <- function(obj,keepGrid=FALSE,value) 
+'ursa_crs<-' <- function(obj,keepGrid=FALSE,value) 
 {
    if ((is.numeric(value))&&(.is.integer(value)))
       value <- paste0("+init=epsg:",round(value))
@@ -37,10 +39,10 @@
    if (!is.ursa(obj)) {
       if (!.is.grid(obj))
          return(NULL)
-      obj$proj4 <- ursa_proj(value)
+      obj$crs <- ursa_proj(value)
       return(obj)
    }
-   obj$grid$proj4 <- ursa_proj(value)
+   obj$grid$crs <- ursa_proj(value)
    if (!keepGrid)
       session_grid(obj)
    obj
